@@ -252,16 +252,104 @@ def Muestra(df1,df2,cve):
     h=df3.iloc[7*n2:8*n2,:]
     i=df3.iloc[8*n2:9*n2,:]
     j=df3.iloc[9*n2:N+1,:]
-    A=a.sample(n=n1)
-    B=b.sample(n=n1)
-    C=c.sample(n=n1)
-    D=d.sample(n=n1)
-    E=e.sample(n=n1)
-    F=f.sample(n=n1)
-    G=g.sample(n=n1)
-    H=h.sample(n=n1)
-    I=i.sample(n=n1)
-    J=j.sample(n=nn-9*n1)
+    if n1==n2:
+        A=a.sample(n=n1)
+        B=b.sample(n=n1)
+        C=c.sample(n=n1)
+        D=d.sample(n=n1)
+        E=e.sample(n=n1)
+        F=f.sample(n=n1)
+        G=g.sample(n=n1)
+        H=h.sample(n=n1)
+        I=i.sample(n=n1)
+        J=j.sample(n=nn-9*n1)
+    else:
+        k,n3=0,n1
+        while 10*n1+k<nn:
+            k=k+1
+            n3=n3+1
+            A=a.sample(n=n3)
+            if 10*n1+k==nn:
+                B=b.sample(n=n1)
+                C=c.sample(n=n1)
+                D=d.sample(n=n1)
+                E=e.sample(n=n1)
+                F=f.sample(n=n1)
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break   
+            k=k+1
+            B=b.sample(n=n3)
+            if 10*n1+k==nn:
+                C=c.sample(n=n1)
+                D=d.sample(n=n1)
+                E=e.sample(n=n1)
+                F=f.sample(n=n1)
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break
+            k=k+1
+            C=c.sample(n=n3)
+            if 10*n1+k==nn:
+                D=d.sample(n=n1)
+                E=e.sample(n=n1)
+                F=f.sample(n=n1)
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break  
+            k=k+1
+            D=d.sample(n=n3)
+            if 10*n1+k==nn:
+                E=e.sample(n=n1)
+                F=f.sample(n=n1)
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break 
+            k=k+1
+            E=e.sample(n=n3)
+            if 10*n1+k==nn:
+                F=f.sample(n=n1)
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break 
+            k=k+1
+            F=f.sample(n=n3)
+            if 10*n1+k==nn:
+                G=g.sample(n=n1)
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break
+            k=k+1
+            G=g.sample(n=n3)
+            if 10*n1+k==nn:
+                H=h.sample(n=n1)
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break 
+            k=k+1
+            H=h.sample(n=n3)
+            if 10*n1+k==nn:
+                I=i.sample(n=n1)
+                J=j.sample(n=n1)
+                break 
+            k=k+1
+            I=i.sample(n=n3)
+            if 10*n1+k==nn:
+                J=j.sample(n=n1)
+                break 
+            k=k+1
+            J=j.sample(n=n3)
     MuestraML=pd.concat([A,B,C,D,E,F,G,H,I,J],sort=False)
     MuestraML=datosduplicados(MuestraML,False)
     MuestraAVM=pd.merge(df2,MuestraML, how="right", 
